import * as React from "react";
import {
  Box,
  Container,
  Card,
  CardHeader,
  CardActions,
  CardContent,
  TextField,
  Divider,
  Switch,
  Typography,
  Autocomplete,
  List,
  ListItem,
  ListItemText,
  IconButton,
  Tooltip,
  Button,
  ListItemAvatar,
  ListItemButton,
  Avatar,
  Stack,
  Popover,
  Checkbox,
  Chip,
  Collapse,
} from "@mui/material";
import Grid from "@mui/material/Unstable_Grid2"; // Grid version 2
import {
  DragIndicator as DragIndicatorIcon,
  RemoveCircle as RemoveCircleIcon,
  AddCircle as AddCircleIcon,
  TextFields as TextFieldsIcon,
  ExpandMore as ExpandMoreIcon,
  Edit as EditIcon,
  Add as AddIcon,
  Cancel as CancelIcon,
  CheckCircleRounded as CheckCircleIcon,
  ContentCopy as ContentCopyIcon,
} from "@mui/icons-material";
import { styled } from "@mui/material/styles";
import { FormatSize } from "../../theme/SvgIcon/SvgIcon";
import RenderWorkflowLevels from "./WorkFlowLevelNew";
import SnackbarNotification from "../../component/notification/SnackbarNotification";
import _ from "lodash";

const PageToolbar = styled("div")(({ theme }) => ({
  background: "#ffffff",
  position: "sticky",
  top: "0",
  width: "100%",
  minHeight: "55px",
  padding: "10px 16px",
  zIndex: "99",
}));

const label = { inputProps: { "aria-label": "Switch demo" } };

const DocumentOption = [
  { label: "PO Line Item" },
  { label: "Externa Inspection" },
];

const CategorySelect = [
  { title: "Rakesh PR Category" },
  { title: "Mobile" },
  { title: "Mobile_Client" },
  { title: "Raw Material" },
  { title: "Annexure 2.5MT" },
];

const PPBagsSelect = [
  { title: "LLP Bags" },
  { title: "PP Bags" },
  { title: "Other" },
];

const PlantSelect = [
  { title: "Ahmedabad" },
  { title: "Jaipur" },
  { title: "Mumbai" },
  { title: "Surat" },
];

const ExpandMore = styled((props) => {
  const { expand, ...other } = props;
  return <IconButton {...other} />;
})(({ theme, expand }) => ({
  transform: !expand ? "rotate(0deg)" : "rotate(180deg)",
  marginLeft: "auto",
  transition: theme.transitions.create("transform", {
    duration: theme.transitions.duration.shortest,
  }),
}));

const WorkFlow = React.forwardRef((props, ref) => {
  const {
    NewData,
    ApproverData,
    WorkFlowData,
    wfStatus,
    setRulesValue,
    accountType, client, userId
  } = props;
  const [open, setOpen] = React.useState(true);
  const [documentOptions, setDocumentOptions] = React.useState([]);
  const [docSelected, setDocSelected] = React.useState({});

  const [workflowDesc, setWorkflowDesc] = React.useState("");
  const [workflowTitle, setWorkflowTitle] = React.useState("");
  const [docRulesFields, setDocRulesFields] = React.useState([]);
  const [jsxRulesFields, setJsxRulesFields] = React.useState([]);
  const [workflowStatus, setWorkflowStatus] = React.useState("create");
  const [isWorkflowActive, setIsWorkflowActive] = React.useState(true);

  const [isCloneWorkflow, setIsCloneWorkflow] = React.useState(false);
  const [cloneDocSelected, setCloneDocSelected] = React.useState({});
  const [cloneDocRulesFields, setCloneDocRulesFields] = React.useState([]);
  const [cloneJsxRulesFields, setCloneJsxRulesFields] = React.useState([]);
  const [rulesValues, setRulesValues] = React.useState([]);
  const obj1 = {
    level: 1,
    levelName: "Level 1",
    userList: [],
    condition: "in",
    attribute_id: "user_ids",
  };
  const obj2 = {
    level: 2,
    levelName: "Level 2",
    userList: [],
    condition: "in",
    attribute_id: "user_ids",
  };
  const [selectedApproverList, setSelectedApproverList] = React.useState([
    obj1,
    obj2,
  ]);
  const [notification, setNotification] = React.useState([]);

  const cloneWorkflow = () => {
    setWorkflowStatus("create");
    setIsCloneWorkflow(true);
    setCloneDocSelected(docSelected);
    setCloneDocRulesFields(docRulesFields);
    setCloneJsxRulesFields(jsxRulesFields);
    setNotification({
      open: true,
      message: "Clone successfully done",
      type: "success",
    });
  };

  React.useImperativeHandle(ref, () => ({
    showNotification(obj) {
      setNotification(obj);
    },
  }));

  React.useEffect(() => {
    setDocumentOptions([...NewData.document]);
    if (wfStatus == "update") {
      setWorkflowStatus("update");
      getRuleDropDown(
        NewData.document.find(
          (option) => option.id == WorkFlowData.service.document
        )
      );
      setWorkflowDesc(WorkFlowData.meta.description);
      setWorkflowTitle(WorkFlowData.meta.name);
    } else {
      getRuleDropDown(NewData.document[0]);
      setAllApprovers(ApproverData);
    }
  }, []);

  const getRuleDropDown = (document) => {
    let tempDocArray = [];
    if (document && document?.rules_attributes) {
      document.rules_attributes.map((rule, i) => {
        let obj = {};
        obj.id = rule.id;
        obj.label = rule.label;
        obj.condition_type = rule.condition_type;
        obj.visible = rule.visible;
        if (rule.condition_type == "in") {
          if (rule.value) {
            obj.optionList = rule.value;
          } else {
            obj.optionList = setRulesValue(document.id, rule.id);
          }
        }
        if (
          wfStatus == "update" &&
          document?.id == WorkFlowData?.service?.document
        ) {
          if (rule.condition_type == "in") {
            const val = WorkFlowData.rules.find(
              (option) => rule.id == option.attribute_id
            );
            if (val) {
              obj.value = obj.optionList.filter((ele) =>
                val.value.includes(ele.id)
              );
            } else {
              obj.value = [];
            }
          } else if (rule.condition_type == "equal") {
            const val = WorkFlowData.rules.find(
              (option) => rule.id == option.attribute_id
            );
            if (val) {
              obj.value = val.value;
            } else {
              obj.value = "";
            }
          }
        } else {
          if (rule.condition_type == "in") {
            obj.value = [];
          } else if (rule.condition_type == "equal") {
            obj.value = "";
          }
        }
        tempDocArray.push(obj);
      });
    }
    let newDoc = { ...document, rules_attributes: tempDocArray };
    setDocSelected(newDoc);
  };

  React.useEffect(() => {
  }, [docSelected, docRulesFields, jsxRulesFields]);

  React.useEffect(() => {
    getFields();
  }, [docSelected]);

  React.useEffect(() => {
    docRulesFields.map((element, i) => {
      let tempoptionList = [];
      if (element.condition_type == "in") {
        let tempoptionListArr = docRulesFields.filter(
          (d) => d.id == element.id
        );
        tempoptionList = tempoptionListArr[0].optionList;
      }
      if (element.visible) {
        setJsxRulesFields((prevState) => [
          ...prevState,
          element.condition_type == "equal" ||
            element.condition_type == "equal_to" ? (
            <Grid key={element.id} xs={12} md={12}>
              <Typography className="TextLabel">{element?.label}</Typography>
              <TextField
                id={element.id}
                defaultValue={element.value}
                placeholder={element?.label}
                fullWidth
                size="small"
                onBlur={(e) => {
                  handleRulesChange(e, element.id);
                }}
              />
            </Grid>
          ) : (
            <Grid key={element.id} xs={12} md={12}>
              <Typography className="TextLabel">{element?.label}</Typography>
              <Autocomplete
                multiple
                limitTags={2}
                id={element.id}
                options={tempoptionList || []}
                getOptionLabel={(option) =>
                  option.label ? option?.label : option.name ? option?.name : ""
                }
                // defaultValue={[CategorySelect[3], CategorySelect[2], CategorySelect[4]]}
                defaultValue={element.value || []}
                // defaultValue={tempoptionList || []}
                renderInput={(params) => (
                  <TextField {...params} label="" placeholder="" />
                )}
                fullWidth
                size="small"
                onChange={(e, value) => {
                  handleAutoComplete(value, element.id);
                }}
              />
            </Grid>
          ),
        ]);
      }
    });
  }, [docRulesFields]);

  const getFields = () => {
    setJsxRulesFields([]);
    setDocRulesFields([]);
    setRulesValues([]);
    if (docSelected && docSelected.rules_attributes) {
      docSelected.rules_attributes.map((element, i) => {
        let valueEle = element.value;
        if (typeof element.value !== "string") {
          valueEle = element.value.map(val => val.id)
        }
        if (workflowStatus == "update") {
          setRulesValues((prevState) => [
            ...prevState,
            {
              attribute_id: element.id,
              condition: element.condition_type,
              value: valueEle,
            },
          ]);
          element.condition_type == "equal"
            ? setDocRulesFields((prevState) => [
              ...prevState,
              {
                id: element.id,
                label: element.label,
                visible: element.visible,
                condition_type: element.condition_type,
                value: element.value ? element?.value : "",
              },
            ])
            : element.condition_type == "in" &&
            setDocRulesFields((prevState) => [
              ...prevState,
              {
                id: element.id,
                label: element.label,
                visible: element.visible,
                condition_type: element.condition_type,
                value: element.value ? element?.value : [],
                optionList: element.optionList ? element?.optionList : [],
              },
            ]);
        } else {
          setRulesValues((prevState) => [
            ...prevState,
            {
              attribute_id: element.id,
              condition: element.condition_type,
              value: element.condition_type == "equal" ? "" : [],
            },
          ]);
          element.condition_type == "equal"
            ? setDocRulesFields((prevState) => [
              ...prevState,
              {
                id: element.id,
                label: element.label,
                visible: element.visible,
                condition_type: element.condition_type,
                value: "",
              },
            ])
            : element.condition_type == "in" &&
            setDocRulesFields((prevState) => [
              ...prevState,
              {
                id: element.id,
                label: element.label,
                visible: element.visible,
                condition_type: element.condition_type,
                value: "",
                optionList: element.optionList ? element?.optionList : [],
              },
            ]);
        }
      });
    }
  };

  const handleExpandClick = () => {
    setOpen(!open);
  };

  //popover
  const [anchorPopover, setAnchorPopover] = React.useState(null);
  const PopoverOpen = Boolean(anchorPopover);
  const id = PopoverOpen ? "simple-popover" : undefined;
  //end popover

  const [visible, setVisible] = React.useState(false);
  const [allSelectedUsers, setAllSelectedUsers] = React.useState([]);
  const [currentLevel, setCurrentLevel] = React.useState(1);
  const [popoverList, setPopoverList] = React.useState([]);
  const [allApprovers, setAllApprovers] = React.useState([]);

  React.useEffect(() => {
    setPopoverList(
      ApproverData.filter((el) => !allSelectedUsers.includes(el.id))
    );
  }, [allSelectedUsers]);

  const addLevel = () => {
    const newLevelNo =
      selectedApproverList[selectedApproverList.length - 1].level + 1;
    let tempSelectedApproverList = [
      ...selectedApproverList,
      {
        level: newLevelNo,
        levelName: `Level ${newLevelNo}`,
        userList: [],
        condition: "in",
        attribute_id: "user_ids",
      },
    ];
    setSelectedApproverList([...tempSelectedApproverList]);
  };

  React.useEffect(() => {
    if (workflowStatus == "update") {
      let tempApproverList = [];
      WorkFlowData.levels.steps.map((el, i) => {
        let tempuserList = [];
        el.conditions[0].value.map((val, i) => {
          tempuserList = [...tempuserList, val];
        });
        tempApproverList = [
          ...tempApproverList,
          {
            level: el.step_sequence_id,
            levelName: el.step_name,
            userList: [...tempuserList],
            is_deleted: el.hasOwnProperty('is_deleted') ? el.is_deleted : false,
            condition: "in",
            attribute_id: "user_ids",
          },
        ];
      });
      setSelectedApproverList([...tempApproverList]);
    }
  }, [workflowStatus]);

  const handleRulesChange = (e, Field) => {
    const { value, type, checked } = e.target;
    const val = type !== "checkbox" ? value : checked;
    setRulesValues((prevState) => {
      return prevState.map((item) => {
        return item.attribute_id === Field ? { ...item, value: val } : item;
      });
    });
  };

  const handleAutoComplete = (val, Field) => {
    let newVal = val?.map((a, i) => a.id);
    setRulesValues((prevState) => {
      return prevState.map((item) => {
        return item.attribute_id === Field ? { ...item, value: newVal } : item;
      });
    });
  };

  const submitData = () => {
    let tempApproverList;
    tempApproverList = selectedApproverList;
    let steps = tempApproverList?.map((level, id) => {
      let obj = {};
      obj["step_name"] = level.levelName;
      if (workflowStatus == "update") {
        obj["step_sequence_id"] = level.level;
        obj["is_deleted"] = level.is_deleted;
      }
      let conditionsArr = [];
      let conditionObj = {
        value: level.userList,
        condition: level.condition,
        attribute_id: level.attribute_id,
      };
      conditionsArr.push(conditionObj);
      obj["conditions"] = conditionsArr;
      return obj;
    });
    let temprulesValues = rulesValues;
    let accountIndex = rulesValues.findIndex(x => x.attribute_id == "account");

    if (workflowStatus !== "update") {
      if (accountIndex > -1) {
        temprulesValues[accountIndex].value = accountType;
      } else {
        let accountObj = {
          "attribute_id": "account",
          "condition": "equal",
          "value": accountType
        }
        temprulesValues.push(accountObj)
      }
    }
    const Payload = {
      name: workflowTitle,
      description: workflowDesc,
      user: userId,
      client: client,
      document: docSelected.id,
      status: isWorkflowActive ? "active" : "inactive",
      rules: temprulesValues.filter((rule, i) => {
        if (rule.value.length > 0) {
          return rule;
        }
      }),
      levels: {
        steps: steps,
      },
    };
    if (workflowStatus == "update") {
      Payload.id = WorkFlowData.id;
    }
    props.handleSubmit(Payload);
  };

  return (
    <React.Fragment>
      <main
        style={{
          width: "100%",
          maxWidth: "100%",
        }}
      >
        <SnackbarNotification onRender={notification} />
        <PageToolbar className="datagrid-PageToolbar head-datagrid-toolbar">
          <Stack spacing={2} direction="row" alignItems={"center"}>
            <Typography className="app-pagetitle">Workflow</Typography>

            <Stack direction="row" alignItems={"center"} ml={"auto !important"}>
              {workflowStatus == 'update' && <IconButton
                sx={{ mr: 2 }}
                aria-label="clone-workflow"
                size="medium"
                onClick={cloneWorkflow}
              >
                <ContentCopyIcon fontSize="inherit" />
              </IconButton>}
              <Button
                variant="outlined"
                sx={{ mr: 2 }}
                size="small"
                onClick={() => {
                  props.handleCancle();
                }}
              >
                Cancel
              </Button>
              <Button
                variant="contained"
                size="small"
                onClick={() => {
                  submitData();
                }}
              >
                Submit
              </Button>
            </Stack>
          </Stack>
        </PageToolbar>

        <Container maxWidth="md" sx={{ mt: 5, mb: 5 }}>
          <Box className="workflow-details">
            <Card variant="outlined">
              <CardContent>
                <Box components="form" className="form-wrapper">
                  <Grid
                    container
                    spacing={2}
                    sx={{ alignItems: "center", mt: 1 }}
                  >
                    <Grid xs={12} sm={8} md={6}>
                      <Box sx={{ display: "flex", alignItems: "center" }}>
                        <FormatSize
                          sx={{
                            marginRight: "5px",
                            color: "var(--bluegrey-600)",
                          }}
                        />
                        <TextField
                          required
                          id="outlined-required"
                          label="Workflow Title"
                          value={workflowTitle}
                          onChange={(e) => setWorkflowTitle(e.target.value)}
                          fullWidth
                          size="small"
                        />
                      </Box>
                    </Grid>
                    <Grid xs={12} sm={4} md={6}>
                      <Box
                        sx={{
                          display: "flex",
                          alignItems: "center",
                          justifyContent: "end",
                        }}
                      >
                        <Typography
                          variant="span"
                          sx={{
                            fontWeight: 500,
                            fontSize: "14px",
                            marginRight: "10px",
                          }}
                        >
                          Active
                        </Typography>
                        <Switch
                          {...label}
                          checked={isWorkflowActive}
                          onChange={(e) =>
                            setIsWorkflowActive(e.target.checked)
                          }
                        />
                      </Box>
                    </Grid>
                  </Grid>

                  <Divider sx={{ mt: 3, mb: 3 }} />

                  <Grid container spacing={2} sx={{ alignItems: "center" }}>
                    {false && (
                      <Grid xs={12} sm={6} md={4}>
                        <Typography className="TextLabel">
                          Company Name
                        </Typography>
                        <TextField
                          required
                          id="outlined-required"
                          defaultValue="Ahm_VendX_Live"
                          fullWidth
                          size="small"
                        />
                      </Grid>
                    )}
                    <Grid xs={12} sm={6} md={4}>
                      <Typography className="TextLabel">Document</Typography>
                      <Autocomplete
                        disablePortal
                        id="document"
                        options={documentOptions}
                        value={docSelected}
                        onChange={(e, val) => {
                          getRuleDropDown(val);
                        }}
                        getOptionLabel={(option) =>
                          option.label ? option?.label : ""
                        }
                        renderInput={(params) => (
                          <TextField {...params} label="" />
                        )}
                        fullWidth
                        size="small"
                      />
                    </Grid>
                    <Grid xs={12} sm={6} md={4}>
                      &nbsp;
                    </Grid>
                  </Grid>

                  <Grid
                    container
                    spacing={2}
                    sx={{ alignItems: "center", mt: 2 }}
                  >
                    <Grid xs={12} sm={12} md={12}>
                      <Typography className="TextLabel">Description</Typography>
                      <TextField
                        id="description"
                        label=""
                        multiline
                        rows={2}
                        placeholder="Add Description here"
                        value={workflowDesc}
                        onChange={(e) => setWorkflowDesc(e.target.value)}
                        fullWidth
                        sx={{
                          "& .MuiInputBase-root": { padding: "13px" },
                        }}
                      />
                    </Grid>
                  </Grid>
                </Box>
              </CardContent>
            </Card>

            <Card variant="outlined" sx={{ mt: 2 }}>
              <CardHeader title="Rules" className="CardHeader" />
              <Divider />
              <CardContent>
                <Box components="form" className="form-wrapper">
                  <Grid container spacing={2} sx={{ alignItems: "center" }}>
                    {jsxRulesFields.map((el, i) => el)}
                  </Grid>
                </Box>
              </CardContent>
            </Card>

            <Card variant="outlined" sx={{ mt: 2 }}>
              <CardHeader title="Levels" className="CardHeader" />
              <Divider />
              <CardContent
                sx={{
                  "&.MuiCardContent-root": {
                    paddingLeft: "8px",
                  },
                }}
              >
                {selectedApproverList &&
                  selectedApproverList.length > 0 &&
                  selectedApproverList.map((el) => (
                    <RenderWorkflowLevels
                      key={el.level}
                      levelEl={el}
                      selectedApproverList={selectedApproverList}
                      setSelectedApproverList={setSelectedApproverList}
                      WorkFlowData={WorkFlowData}
                      workflowStatus={workflowStatus}
                      ApproverData={ApproverData}
                      setAllApprovers={setAllApprovers}
                    />
                  ))}

                {workflowStatus != "update" && (
                  <CardActions>
                    <Button
                      variant="contained"
                      startIcon={<AddIcon />}
                      size="small"
                      disabled={workflowStatus == "update" ? true : false}
                      onClick={addLevel}
                    >
                      ADD LEVEL
                    </Button>
                  </CardActions>
                )}
              </CardContent>
            </Card>
          </Box>
        </Container>
      </main>
    </React.Fragment>
  );
});

export default WorkFlow;
