import * as React from "react";
import {
  Box,
  Switch,
  Typography,
  Button,
  Stack,
  ButtonGroup,
  Paper,
  Chip,
} from "@mui/material";
import { styled } from "@mui/material/styles";
import Grid from "@mui/material/Unstable_Grid2";
import {
  DataGridPro,
  GridToolbarQuickFilter,
  GridToolbarContainer,
  GridToolbarFilterButton,
  GridToolbarColumnsButton,
  GridToolbarDensitySelector,
  GridToolbarExport,
  GridFooterContainer,
  GridFooter,
  GridActionsCellItem,
} from "@mui/x-data-grid-pro";
import WorkflowTabs from "./WorkflowListTabs.js";
import { Add, MoreVert, Remove } from "@mui/icons-material";
import moment from "moment";
import SnackbarNotification from "../../component/notification/SnackbarNotification.js";

const PageToolbar = styled("div")(({ theme }) => ({
  background: "#ffffff",
  position: "sticky",
  top: 0,
  width: "100%",
  minHeight: "55px",
  padding: "10px 16px",
  zIndex: "99",
}));

function DetailPanelContent({
  row,
  ApproverRestructureJson,
  restructureJson,
  NewData,
  RulesData,
}) {
  return (
    <Stack
      sx={{ height: "100%", borderBottom: "1px solid var(--bluegrey-500)" }}
    >
      <Paper
        sx={{
          flex: 1,
          mx: "auto",
          width: "100%",
          padding: "0 35px 10px 35px",
          borderRadius: "0",
          boxShadow: "none",
        }}
      >
        <Stack sx={{ height: 1, width: "calc(100% - 75px)" }}>
          <WorkflowTabs
            row={row}
            ApproverRestructureJson={ApproverRestructureJson}
            NewData={NewData}
            restructureJson={restructureJson}
            RulesData={RulesData}
          />
        </Stack>
      </Paper>
    </Stack>
  );
}

function CustomGridToolbar() {
  return (
    <React.Fragment>
      <GridToolbarContainer className="datagrid-toolbar">
        <Grid
          container
          spacing={0}
          sx={{
            width: "100%",
            pt: 1,
            "&.MuiGrid2-root": {
              paddingTop: { xs: "0", sm: "0", md: "0", alignItems: "center" },
            },
          }}
        >
          <Grid xs={12} sm={12} md={3} xl={4}>
            <Box sx={{ display: "flex", alignItems: "center", gap: 1 }}>
              <GridToolbarQuickFilter
                className="DataGrid-SearchBar"
                sx={{ pb: 0 }}
              />
            </Box>
          </Grid>

          <Grid
            xs={12}
            sm={12}
            md={9}
            xl={8}
            sx={{ display: { xs: "none", sm: "none", md: "flex" } }}
          >
            <Box className="toolbar-right">
              <Box sx={{ display: "flex", alignItems: "center", gap: 1 }}></Box>
              <Box className="dg-filter">
                <GridToolbarColumnsButton />
                <GridToolbarDensitySelector />
                <GridToolbarExport />
                <GridToolbarFilterButton />
              </Box>
            </Box>
          </Grid>
        </Grid>
      </GridToolbarContainer>

      <GridToolbarContainer
        className="datagrid-toolbar"
        sx={{ display: { sm: "flex", md: "none" } }}
      >
        <Grid
          container
          spacing={0}
          sx={{ width: "100%", alignItems: "center" }}
        >
          <Grid xs={2} md={6}>
            <Box></Box>
          </Grid>
          <Grid xs={10} md={6} sx={{ textAlign: { xs: "right", sm: "right" } }}>
            <Box className="dg-filter">
              <GridToolbarColumnsButton />
              <GridToolbarDensitySelector />
              <GridToolbarExport />
              <GridToolbarFilterButton />
            </Box>
          </Grid>
        </Grid>
      </GridToolbarContainer>
    </React.Fragment>
  );
}

const SwitchLabel = { inputProps: { "aria-label": "Switch" } };

export function CustomExpandIcon() {
  return <Add className="icon" />;
}

export function CustomCollapseIcon() {
  return <Remove className="icon" />;
}

function WorkFlowList(props) {
  const rows = props.WorkflowListData;
  const ApproverRestructureJson = props.restructureJson(
    props.ApproverData,
    "id",
    "name"
  );

  const getDetailPanelContent = React.useCallback(({ row }) => {
    return (
      <DetailPanelContent
        row={row}
        ApproverRestructureJson={ApproverRestructureJson}
        restructureJson={props.restructureJson}
        NewData={props.NewData}
        RulesData={props.RulesData}
      />
    );
  }, []);

  const getDetailPanelHeight = React.useCallback(() => 300, []);

  const editWorkflow = (param) => {
    props.handleWorkflowEdit(param.row);
  };

  const columns = [
    {
      field: "more",
      type: "actions",
      headerName: "",
      width: 30,
      align: "center",
      getActions: (params) => [
        <GridActionsCellItem
          label="Edit"
          onClick={() => editWorkflow(params)}
          showInMenu
        />,
      ],
    },
    {
      field: "WorkflowTitle",
      headerName: "Workflow Title",
      width: 160,
      renderCell: (row) => {
        return (
          <Typography variant="body2" sx={{ fontWeight: "500" }}>
            {row.row.meta.name}
          </Typography>
        );
      },
      valueGetter: (params) => params.row.meta.name,
    },
    {
      field: "Status",
      headerName: "Status",
      width: 160,
      renderCell: (row) => {
        return (
          <React.Fragment>
            {row.row.meta.status == "active" && (
              <Chip
                label="Active"
                color="success"
                size="small"
                variant="soft"
              />
            )}
            {row.row.meta.status == "inactive" && (
              <Chip label="Inactive" size="small" variant="soft" />
            )}
            {row.row.meta.status == "lock" && (
              <Chip label="Locked" color="error" size="small" variant="soft" />
            )}
          </React.Fragment>
        );
      },
      valueGetter: (params) => params.row.meta.status,
    },
    {
      field: "discription",
      headerName: "Discription",
      width: 275,
      renderCell: (row) => {
        return (
          <Typography variant="body2" sx={{ fontWeight: "500" }}>
            {row.row.meta.description}
          </Typography>
        );
      },
      valueGetter: (params) => params.row.meta.description,
    },
    {
      field: "document",
      headerName: "Document",
      width: 275,
      renderCell: (row) => {
        let currentDoc = props.NewData.document.find(
          (ele) => ele.id == row.row.service.document
        );
        return (
          <Typography variant="body2" sx={{ fontWeight: "500" }}>
            {currentDoc ? currentDoc.label : ""}
          </Typography>
        );
      },
      valueGetter: (params) => {
        let currentDoc = props.NewData.document.find(
          (ele) => ele.id == params.row.service.document
        );
        return currentDoc ? currentDoc.label : "";
      },
    },
    {
      field: "Date",
      headerName: "Date",
      width: 160,
      renderCell: (row) => {
        return (
          <Typography variant="body2" sx={{ fontWeight: "500" }}>
            {row.row.meta.updated_datetime}
          </Typography>
        );
      },
      valueGetter: (params) => {
        params.row.meta.updated_datetime;
      },
    },
  ];

  function CustomFooter() {
    return (
      <GridFooterContainer
        sx={{ justifyContent: "end" }}
        className="GridFooterContainerInvoice"
      >
        <Typography variant="h7">
          Total Order Line items : {rows.length}
        </Typography>
        <GridFooter
          sx={{
            border: "none", // To delete double border.
          }}
        />
      </GridFooterContainer>
    );
  }

  return (
    <main
      style={{
        width: "100%",
        maxWidth: "100%",
        padding: 0,
      }}
    >
      {props.snackbarObj && (
        <SnackbarNotification onRender={props.snackbarObj} />
      )}
      <PageToolbar className="datagrid-PageToolbar head-datagrid-toolbar">
        <Stack spacing={2} direction="row" alignItems={"center"}>
          <Typography className="app-pagetitle">Workflow</Typography>

          <ButtonGroup
            variant="contained"
            aria-label="split button"
            sx={{ ml: "auto !important" }}
          >
            <Button
              variant="contained"
              size="small"
              onClick={() => {
                props.handleNewWorkflow();
              }}
            >
              + New Workflow
            </Button>
          </ButtonGroup>
        </Stack>
      </PageToolbar>

      <div className="DataGFullScreen-wrap">
        <DataGridPro
          rows={rows}
          columns={columns}
          headerHeight={40}
          disableSelectionOnClick
          pagination
          components={{
            Toolbar: CustomGridToolbar,
            Footer: CustomFooter,
          }}
          className="fullScreenGrid"
          sx={{
            "&.MuiDataGrid-root": {
              border: 0,
            },
            "& .MuiDataGrid-virtualScrollerContent--overflowed .MuiDataGrid-row--lastVisible .MuiDataGrid-cell":
            {
              borderBottomColor: "#a6c1d3",
            },
          }}
          getDetailPanelHeight={getDetailPanelHeight}
          getDetailPanelContent={getDetailPanelContent}
        />
      </div>
    </main>
  );
}

export default WorkFlowList;
