import * as React from 'react';
import { Box, Container, Card, CardHeader, CardActions, CardContent, TextField, Divider, Switch, Typography, FormControl, InputLabel, Input, OutlinedInput, Select, MenuItem, TextareaAutosize, Autocomplete, List, ListItem, ListItemIcon, ListItemText, TableContainer, Table, TableBody, TableRow, TableCell, IconButton, Tooltip, Button, Accordion, AccordionSummary, AccordionDetails, ListItemAvatar, Avatar, Stack, Popover } from '@mui/material';
import Grid from '@mui/material/Unstable_Grid2'; // Grid version 2
import DragIndicatorIcon from '@mui/icons-material/DragIndicator';
import RemoveCircleIcon from '@mui/icons-material/RemoveCircle';
import AddCircleIcon from '@mui/icons-material/AddCircle';
import TextFieldsIcon from '@mui/icons-material/TextFields';
import ExpandMoreIcon from '@mui/icons-material/ExpandMore';
import EditIcon from '@mui/icons-material/Edit';
import AddIcon from '@mui/icons-material/Add';
import Collapse from '@mui/material/Collapse';
import { styled } from '@mui/material/styles';

const PageToolbar = styled('div')(({theme}) => ({   
    background: '#ffffff',
    // position: 'sticky',
    // top: 0,
    width: '100%',
    minHeight: '50px',
    padding: '0 20px',
    display:'inline-flex'
}));

const label = { inputProps: { 'aria-label': 'Switch demo' } };

const DocumentOption = [
    { label: 'PO Line Item' },
    { label: 'Externa Inspection' },
]

const CityName = [
    { title: 'Ahmedabad' },
    { title: 'Mumbai'},
    { title: 'Surat'},
    { title: 'Pune'},
    { title: 'Delhi'},
    { title: "Banglor"},
  ];

const ExpandMore = styled((props) => {
    const { expand, ...other } = props;
    return <IconButton {...other} />;
  })(({ theme, expand }) => ({
    transform: !expand ? 'rotate(0deg)' : 'rotate(180deg)',
    marginLeft: 'auto',
    transition: theme.transitions.create('transform', {
      duration: theme.transitions.duration.shortest,
    }),
  }));

function WorkFlow() {
    const [expanded, setExpanded] = React.useState(false);

    const handleExpandClick = () => {
        setExpanded(!expanded);
    };

    const [fieldName, setfieldName] = React.useState('10');
    const [ConditionSelect, setConditionSelect] = React.useState('10');
    const [ValueSelect, setValueSelect] = React.useState('10');

    const ChangeName = (event) => {
        setfieldName(event.target.value);
    };

    const ConditionChange = (event) => {
        setConditionSelect(event.target.value);
    };

    const ValueChange = (event) => {
        setValueSelect(event.target.value);
    };

    //popover
    const [anchorPopover, setAnchorPopover] = React.useState(null);

    const handleClick = (event) => {
        setAnchorPopover(event.currentTarget);
    };
  
    const handleClose = () => {
        setAnchorPopover(null);
    };
  
    const PopoverOpen = Boolean(anchorPopover);
    const id = PopoverOpen ? 'simple-popover' : undefined;
    //end popover 

    return(
        <>
        <PageToolbar className="pageHeaderBar">
            <Stack spacing={2} direction="row" alignItems={"center"} width={"100%"}>
                <Typography variant='h6' color={'var(--bluegrey-900)'} fontWeight={'500'}>Workflow</Typography>

                <Stack direction="row" alignItems={"center"} ml={'auto !important'}>
                    <Button variant="outlined" sx={{mr:2}} size='small'>Cancle</Button>
                    <Button variant="contained" size='small'>Submit</Button>                
                </Stack>
            </Stack>
        </PageToolbar>

        <Container maxWidth="md" sx={{mt:5, mb:5}}>
            <Box className="workflow-details">
                <Card variant="outlined">
                    <CardContent>
                        <Box
                            components="form"   
                            className="form-wrapper"                                                     
                        >
                            <Grid container  spacing={2}  sx={{alignItems:'center', mt:1}}>
                                <Grid xs={12} sm={8} md={6}>
                                    <Box sx={{display:'flex', alignItems:'center'}}>
                                        <TextFieldsIcon sx={{marginRight:'5px', color:'var(--bluegrey-600)' }}/>
                                        <TextField required  id="outlined-required" label="Workflow Title" defaultValue="PP Bags Flow" fullWidth size="small" />
                                    </Box>
                                </Grid>
                                <Grid xs={12} sm={4} md={6}>
                                    <Box sx={{display:'flex', alignItems:'center', justifyContent:'end'}}>
                                        <Typography variant="span" sx={{fontWeight:500, fontSize:'14px', marginRight:'10px'}}>Active</Typography>
                                        <Switch {...label} />
                                    </Box>
                                </Grid>
                            </Grid>
                            
                            <Divider sx={{mt:3, mb:3}}/>

                            <Grid container spacing={2} sx={{alignItems:'center'}}>
                                <Grid xs={12} sm={6} md={4}>
                                    <Typography className="TextLabel">Company Name</Typography>
                                    <TextField required  id="outlined-required" defaultValue="Ahm_VendX_Live" fullWidth size="small" />                                    
                                </Grid>
                                <Grid xs={12} sm={6} md={4}>
                                    <Typography className="TextLabel">Document</Typography>
                                    <Autocomplete
                                        disablePortal
                                        id="document"
                                        options={DocumentOption}
                                        renderInput={(params) => <TextField {...params} label="" />}
                                        fullWidth 
                                        size="small"
                                    />
                                </Grid>
                                <Grid xs={12} sm={6} md={4}>
                                    &nbsp;
                                </Grid>
                            </Grid>

                            <Grid container spacing={2} sx={{alignItems:'center', mt:2}}>
                                <Grid xs={12} sm={12} md={12}>
                                    <Typography className="TextLabel">Description</Typography>
                                    <TextField
                                        id="description"
                                        label=""
                                        multiline
                                        rows={2}
                                        placeholder="Add Description here"
                                        defaultValue=""
                                        fullWidth 
                                    />                                    
                                </Grid>
                            </Grid>
                            
                        </Box>
                    </CardContent>
                </Card>

                <Card variant="outlined" sx={{mt:2}}>
                    <CardHeader                        
                        title="Rules"
                        className="CardHeader"
                    />
                    <Divider />
                    <CardContent>
                        <TableContainer>
                            <Table fullWidth aria-label="">
                                <TableBody>

                                     <TableRow
                                        sx={{ '&.MuiTableRow-root td': { border: 0, padding:'8px 8px 16px 8px' }, '&.MuiTableRow-root td:first-child':{pl:0} }}
                                     >
                                         <TableCell align="left" width={32}>
                                            <IconButton aria-label="" size="small" sx={{p:0}}>
                                                <DragIndicatorIcon />
                                            </IconButton>
                                        </TableCell>
                                         <TableCell align="left" width={250}>
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="field-name-select-label">Field Name</InputLabel>
                                                <Select
                                                    labelId="field-name-select-label"
                                                    id="field-name-select"
                                                    value={fieldName}
                                                    label="Field Name"
                                                    onChange={ChangeName}
                                                >
                                                    <MenuItem value={10}>Category</MenuItem>
                                                    <MenuItem value={20}>Plant</MenuItem>
                                                    <MenuItem value={30}>PP Bags Type</MenuItem>
                                                    <MenuItem value={40}>Material Group</MenuItem>
                                                    <MenuItem value={50}>PO Doc Type</MenuItem>
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="left" width={150}>
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="condition-select-label">Condition</InputLabel>
                                                <Select
                                                    labelId="condition-select-label"
                                                    id="condition-select"
                                                    value={ConditionSelect}
                                                    label="Condition"
                                                    onChange={ConditionChange}
                                                >
                                                    <MenuItem value={10}> = </MenuItem>
                                                    <MenuItem value={20}> != </MenuItem>
                                                    {/* <MenuItem value={30}> > </MenuItem>
                                                    <MenuItem value={40}> >= </MenuItem>
                                                    <MenuItem value={50}> < </MenuItem>
                                                    <MenuItem value={60}> <= </MenuItem> */}
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="left">
                                            <Autocomplete
                                                multiple
                                                limitTags={1}
                                                id="multiple-limit-tags"
                                                options={CityName}
                                                getOptionLabel={(option) => option.title}
                                                defaultValue={[CityName[3], CityName[2], CityName[4]]}
                                                renderInput={(params) => (
                                                <TextField {...params} label="value" placeholder="Favorites" />
                                                )}
                                                fullWidth
                                                size="small"
                                            />
                                         </TableCell>
                                         <TableCell align="center" width={32}>
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                         </TableCell>
                                     </TableRow>

                                     <TableRow
                                        sx={{ '&.MuiTableRow-root td': { border: 0, padding:'8px 8px 16px 8px' }, '&.MuiTableRow-root td:first-child':{pl:0} }}
                                     >
                                         <TableCell align="left" width={32}>
                                            <IconButton aria-label="" size="small" sx={{p:0}}>
                                                <DragIndicatorIcon />
                                            </IconButton>
                                        </TableCell>
                                         <TableCell align="left" width={250}>
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="field-name-select-label">Field Name</InputLabel>
                                                <Select
                                                    labelId="field-name-select-label"
                                                    id="field-name-select"
                                                    value={fieldName}
                                                    label="Field Name"
                                                    onChange={ChangeName}
                                                >
                                                    <MenuItem value={10}>Category</MenuItem>
                                                    <MenuItem value={20}>Plant</MenuItem>
                                                    <MenuItem value={30}>PP Bags Type</MenuItem>
                                                    <MenuItem value={40}>Material Group</MenuItem>
                                                    <MenuItem value={50}>PO Doc Type</MenuItem>
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="left" width={150}>
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="condition-select-label">Condition</InputLabel>
                                                <Select
                                                    labelId="condition-select-label"
                                                    id="condition-select"
                                                    value={ConditionSelect}
                                                    label="Condition"
                                                    onChange={ConditionChange}
                                                >
                                                    <MenuItem value={10}> = </MenuItem>
                                                    <MenuItem value={20}> != </MenuItem>
                                                    {/* <MenuItem value={30}> > </MenuItem>
                                                    <MenuItem value={40}> >= </MenuItem>
                                                    <MenuItem value={50}> < </MenuItem>
                                                    <MenuItem value={60}> <= </MenuItem> */}
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="left">
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="value-select-label">Value</InputLabel>
                                                <Select
                                                    labelId="value-select-label"
                                                    id="value-select"
                                                    value={ValueSelect}
                                                    label="Value"
                                                    onChange={ValueChange}
                                                >
                                                    <MenuItem value={10}>Rakesh PR Categroy</MenuItem>
                                                    <MenuItem value={20}>Mobile Client</MenuItem>
                                                    <MenuItem value={30}>Raw Material</MenuItem>
                                                    <MenuItem value={40}>Annexure 2.5MT</MenuItem>
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="center" width={32}>
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""                                                    
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                         </TableCell>
                                     </TableRow>

                                     <TableRow
                                        sx={{ '&.MuiTableRow-root td': { border: 0, padding:'8px 8px 16px 8px' }, '&.MuiTableRow-root td:first-child':{pl:0} }}
                                     >
                                         <TableCell align="left" width={32}>
                                            <IconButton aria-label="" size="small" sx={{p:0}}>
                                                <DragIndicatorIcon />
                                            </IconButton>
                                        </TableCell>
                                         <TableCell align="left" width={250}>
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="field-name-select-label">Field Name</InputLabel>
                                                <Select
                                                    labelId="field-name-select-label"
                                                    id="field-name-select"
                                                    value={fieldName}
                                                    label="Field Name"
                                                    onChange={ChangeName}
                                                >
                                                    <MenuItem value={10}>Category</MenuItem>
                                                    <MenuItem value={20}>Plant</MenuItem>
                                                    <MenuItem value={30}>PP Bags Type</MenuItem>
                                                    <MenuItem value={40}>Material Group</MenuItem>
                                                    <MenuItem value={50}>PO Doc Type</MenuItem>
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="left" width={150}>
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="condition-select-label">Condition</InputLabel>
                                                <Select
                                                    labelId="condition-select-label"
                                                    id="condition-select"
                                                    value={ConditionSelect}
                                                    label="Condition"
                                                    onChange={ConditionChange}
                                                >
                                                    <MenuItem value={10}> = </MenuItem>
                                                    <MenuItem value={20}> != </MenuItem>
                                                    {/* <MenuItem value={30}> > </MenuItem>
                                                    <MenuItem value={40}> >= </MenuItem>
                                                    <MenuItem value={50}> < </MenuItem>
                                                    <MenuItem value={60}> <= </MenuItem> */}
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="left" >
                                            <FormControl fullWidth size="small">
                                                <InputLabel id="value-select-label">Value</InputLabel>
                                                <Select
                                                    labelId="value-select-label"
                                                    id="value-select"
                                                    value={ValueSelect}
                                                    label="Value"
                                                    onChange={ValueChange}
                                                >
                                                    <MenuItem value={10}>Rakesh PR Categroy</MenuItem>
                                                    <MenuItem value={20}>Mobile Client</MenuItem>
                                                    <MenuItem value={30}>Raw Material</MenuItem>
                                                    <MenuItem value={40}>Annexure 2.5MT</MenuItem>
                                                </Select>
                                            </FormControl>
                                         </TableCell>
                                         <TableCell align="center" width={32}>
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                         </TableCell>
                                     </TableRow>

                                     <TableRow
                                        sx={{ '&.MuiTableRow-root td': { border: 0, padding:'0 8px 0 8px' } }}
                                     >
                                        <TableCell colSpan={5}>
                                            <Button color="primary" startIcon={<AddCircleIcon />} size="large" 
                                                sx={{
                                                    pl:0, 
                                                    pb:0,
                                                    "&:hover": {
                                                        backgroundColor:'transparent'
                                                    } 
                                                }}
                                            >
                                                Add Rules                                                
                                            </Button>
                                        </TableCell>
                                     </TableRow>
                                                                          

                                </TableBody>
                            </Table>
                        </TableContainer>                        
                    </CardContent>
                </Card>

                <Card variant="outlined" sx={{mt:2}}>
                    <CardHeader                        
                        title="0 approvers across 1 levels"
                        className="CardHeader"
                        sx={{'&.MuiCardHeader-root .MuiTypography-h5':{textTransform:'lowercase'}}}
                    />
                    <Divider />
                    <CardContent>

                        <Card sx={{boxShadow:'none'}}>
                            <CardActions sx={{p:0}}>
                                <Box sx={{width:'100%', display:'flex', justifyContent:'space-between'}} className="CardLevel">
                                    <Box sx={{display:'flex', alignItems:'center', background:'var(--bg-white)', zIndex:'11'}}>
                                        <Typography
                                            sx={{
                                                fontSize:'14px', 
                                                fontWeight:'600',
                                                textTransform:'uppercase'
                                            }}                                            
                                        >
                                            Level 1                                        
                                        </Typography>                            
                                        <IconButton aria-label="edit" size="small">
                                            <EditIcon sx={{ fontSize: 18, p:0 }} />
                                        </IconButton>
                                    </Box>
                                    
                                    <Box sx={{background:'var(--bg-white)', zIndex:'11', pl:1}}>
                                        <Button 
                                            variant="outlined" 
                                            onClick={handleClick}
                                            startIcon={<AddIcon sx={{'&.MuiSvgIcon-root':{fontSize:'16px'}}} />} 
                                            size="small" 
                                            sx={{fontSize:'11px', '&.MuiButtonBase-root .MuiButton-startIcon':{marginRight:'2px', marginLeft: '-5px'}}}
                                        >
                                            Add Approver
                                        </Button>
                                        <Popover
                                            id={id}
                                            open={PopoverOpen}
                                            anchorEl={anchorPopover}
                                            onClose={handleClose}
                                            sx={{
                                                '&.MuiPopover-root .MuiPaper-root':{
                                                boxShadow:'0px 0px 7px 1px rgb(0 0 0 / 20%)'}
                                            }}
                                            anchorOrigin={{
                                                vertical: 'bottom',
                                                horizontal: 'right',
                                            }}
                                            transformOrigin={{
                                                vertical: 'top',
                                                horizontal: 'right',
                                            }}
                                        >
                                            <Box className="Level-ApprovDtl Popover-ApprovDtl" sx={{padding:'16px'}}>
                                                <Typography variant="h6" sx={{fontSize:"16px", fontWeight:'500', mb:2}}>Select Approvers</Typography>
                                                <TextField id="outlined-search" label="Search..." type="search" size="small" sx={{mb:1, width:'330px'}} />
                                                <List sx={{overflow:'auto', height:'200px'}}>
                                                    <ListItem alignItems="flex-start">
                                                        <ListItemAvatar>
                                                            <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg" />
                                                        </ListItemAvatar>
                                                        <ListItemText
                                                            primary="Rakesh Vendx"
                                                            secondary={
                                                                <Typography
                                                                    className="mailId"
                                                                    component="span"
                                                                    variant="body2"
                                                                    color="text.primary"
                                                                >
                                                                    rakesh@gmail.com
                                                                </Typography>                                                        
                                                            }
                                                        />
                                                    </ListItem>

                                                    <ListItem alignItems="flex-start">
                                                        <ListItemAvatar>
                                                            <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg" />
                                                        </ListItemAvatar>
                                                        <ListItemText
                                                            primary="Rakesh Vendx"
                                                            secondary={
                                                                <Typography
                                                                    className="mailId"
                                                                    component="span"
                                                                    variant="body2"
                                                                    color="text.primary"
                                                                >
                                                                    rakesh@gmail.com
                                                                </Typography>                                                        
                                                            }
                                                        />
                                                    </ListItem>

                                                    <ListItem alignItems="flex-start">
                                                        <ListItemAvatar>
                                                            <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg" />
                                                        </ListItemAvatar>
                                                        <ListItemText
                                                            primary="Rakesh Vendx"
                                                            secondary={
                                                                <Typography
                                                                    className="mailId"
                                                                    component="span"
                                                                    variant="body2"
                                                                    color="text.primary"
                                                                >
                                                                    rakesh@gmail.com
                                                                </Typography>                                                        
                                                            }
                                                        />
                                                    </ListItem>

                                                    <ListItem alignItems="flex-start">
                                                        <ListItemAvatar>
                                                            <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg" />
                                                        </ListItemAvatar>
                                                        <ListItemText
                                                            primary="Rakesh Vendx"
                                                            secondary={
                                                                <Typography
                                                                    className="mailId"
                                                                    component="span"
                                                                    variant="body2"
                                                                    color="text.primary"
                                                                >
                                                                    rakesh@gmail.com
                                                                </Typography>                                                        
                                                            }
                                                        />
                                                    </ListItem>

                                                    <ListItem alignItems="flex-start">
                                                        <ListItemAvatar>
                                                            <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg" />
                                                        </ListItemAvatar>
                                                        <ListItemText
                                                            primary="Rakesh Vendx"
                                                            secondary={
                                                                <Typography
                                                                    className="mailId"
                                                                    component="span"
                                                                    variant="body2"
                                                                    color="text.primary"
                                                                >
                                                                    rakesh@gmail.com
                                                                </Typography>                                                        
                                                            }
                                                        />
                                                    </ListItem>
                                                    
                                                </List>
                                            </Box>
                                        </Popover>

                                        <ExpandMore
                                            expand={expanded}
                                            onClick={handleExpandClick}
                                            aria-expanded={expanded}
                                            aria-label="show more"
                                            sx={{pr:0}}
                                        >
                                            <ExpandMoreIcon small="small"/>
                                        </ExpandMore>                          
                                    </Box>
                                </Box>

                            </CardActions>

                            <Collapse in={expanded} timeout="auto" unmountOnExit className="Level-CardBox">
                                <CardContent className="Level-ApprovDtl">
                                    <List>
                                        <ListItem alignItems="flex-start">
                                            <IconButton aria-label="" size="small">
                                                <DragIndicatorIcon />
                                            </IconButton>

                                            <ListItemAvatar>
                                                <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg"/>
                                            </ListItemAvatar>
                                            <ListItemText
                                                primary="Rakesh Vendx"                                        
                                            />
                                            
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                        </ListItem>
                                    </List> 
                                    <List>
                                        <ListItem alignItems="flex-start">
                                            <IconButton aria-label="" size="small">
                                                <DragIndicatorIcon />
                                            </IconButton>

                                            <ListItemAvatar>
                                                <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg"/>
                                            </ListItemAvatar>
                                            <ListItemText
                                                primary="Rakesh Vendx"                                        
                                            />
                                            
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                        </ListItem>
                                    </List>    
                                    <List>
                                        <ListItem alignItems="flex-start">
                                            <IconButton aria-label="" size="small">
                                                <DragIndicatorIcon />
                                            </IconButton>

                                            <ListItemAvatar>
                                                <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg"/>
                                            </ListItemAvatar>
                                            <ListItemText
                                                primary="Rakesh Vendx"                                        
                                            />
                                            
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                        </ListItem>
                                    </List>    
                                    <List>
                                        <ListItem alignItems="flex-start">
                                            <IconButton aria-label="" size="small">
                                                <DragIndicatorIcon />
                                            </IconButton>

                                            <ListItemAvatar>
                                                <Avatar alt="Rakesh" src="/static/images/avatar/1.jpg"/>
                                            </ListItemAvatar>
                                            <ListItemText
                                                primary="Rakesh Vendx"                                        
                                            />
                                            
                                            <Tooltip title="Remove">
                                                <IconButton 
                                                    aria-label=""
                                                    sx={{
                                                        color:'#f05043',
                                                        "&:hover": {
                                                            backgroundColor:'rgba(240, 80, 67, 0.04)'
                                                        }                                                        
                                                    }}>
                                                    <RemoveCircleIcon />
                                                </IconButton>
                                            </Tooltip>
                                        </ListItem>
                                    </List>                             
                                </CardContent>
                            </Collapse>
                        </Card> 
                        

                        <Card sx={{boxShadow:'none'}}>
                            <TextField id="outlined-basic" label="Outlined" variant="outlined" fullWidth sx={{mt:2, mb:2}}/>
                            <Button 
                                variant="contained" 
                                startIcon={<AddIcon/>} 
                                size="small"                                     
                            >
                                ADD LEVEL
                            </Button>                            
                        </Card>

                    </CardContent>
                </Card>



            </Box>
        </Container>
        </>
    );
};

export default WorkFlow;