import * as React from "react";
import { Tabs, Tab, Typography, Box } from "@mui/material";
import { DataGridPro } from "@mui/x-data-grid-pro";

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
    <Box
      role="tabpanel"
      hidden={value !== index}
      id={`simple-tabpanel-${index}`}
      aria-labelledby={`simple-tab-${index}`}
      {...other}
    >
      {value === index && <Box sx={{ p: 3 }}>{children}</Box>}
    </Box>
  );
}

export default function BasicTabs({
  row,
  ApproverRestructureJson,
  restructureJson,
  NewData,
  RulesData,
}) {
  const [value, setValue] = React.useState(0);

  const handleChange = (event, newValue) => {
    setValue(newValue);
  };

  let RulesRestructureJson = {};
  let currentDoc = NewData.document.find(
    (ele) => ele.id == row.service.document
  );

  currentDoc.rules_attributes.map((rule, i) => {
    if (rule.value) {
      RulesRestructureJson[rule.id] = restructureJson(rule.value, "id", "name");
    } else if (RulesData[rule.id]) {
      RulesRestructureJson[rule.id] = restructureJson(
        RulesData[rule.id],
        "id",
        "name"
      );
    }
  });

  const rulesRow = row.rules.map((el, i) => ({
    ...el,
    id: i + 1,
  }));

  const levelRow = row.levels.steps.map((el, i) => ({
    id: el.step_sequence_id,
    step_name: el.step_name,
    user: el.conditions[0].value,
  }));

  return (
    <Box>
      <Tabs
        value={value}
        onChange={handleChange}
        aria-label="basic tabs example"
      >
        <Tab label="Rules" sx={{ textTransform: "capitalize" }} />
        <Tab label="Levels" sx={{ textTransform: "capitalize" }} />
      </Tabs>

      <TabPanel value={value} index={0} className="tabs-panel">
        <DataGridPro
          columns={[
            {
              field: "FieldName",
              headerName: "Field Name",
              width: 160,
              renderCell: (row) => {
                return (
                  <Typography variant="body2" sx={{ fontWeight: "500" }}>
                    {row.row.attribute_id}
                  </Typography>
                );
              },
            },
            {
              field: "Condition",
              headerName: "Condition",
              width: 160,

              renderCell: (row) => {
                return (
                  <Typography variant="body2" sx={{ fontWeight: "500" }}>
                    {row.row.condition}
                  </Typography>
                );
              },
            },
            {
              field: "Value",
              headerName: "Value",
              width: 275,
              renderCell: (row) => {
                let tempValue = row.row.value;
                if (
                  typeof row.row.value !== "string" &&
                  RulesRestructureJson[row.row.attribute_id]
                ) {
                  let element = RulesRestructureJson[row.row.attribute_id];
                  tempValue = tempValue.map((key, i) => {
                    return element[key];
                  });
                }
                return (
                  <Typography variant="body2" sx={{ fontWeight: "500" }}>
                    {typeof tempValue == "string"
                      ? tempValue
                      : tempValue.join(", ")}
                  </Typography>
                );
              },
            },
          ]}
          rows={rulesRow}
          sx={{
            height: "220px",
            "&.MuiDataGrid-root": {
              borderRadius: 0,
            },
            "& .MuiDataGrid-main .MuiDataGrid-row--lastVisible .MuiDataGrid-cell":
            {
              borderBottomColor: "transparent",
            },
          }}
          hideFooter
        />
      </TabPanel>
      <TabPanel value={value} index={1} className="tabs-panel">
        <DataGridPro
          columns={[
            {
              field: "Level",
              headerName: "Level",
              width: 160,
              renderCell: (row) => {
                return (
                  <Typography variant="body2" sx={{ fontWeight: "500" }}>
                    {row.row.step_name}
                  </Typography>
                );
              },
            },
            {
              field: "User",
              headerName: "User",
              width: 275,
              renderCell: (row) => {
                let userVal = row.row.user.map((val, i) => {
                  return ApproverRestructureJson[val];
                });
                return (
                  <Typography variant="body2" sx={{ fontWeight: "500" }}>
                    {userVal.join(", ")}
                  </Typography>
                );
              },
            },
          ]}
          rows={levelRow}
          sx={{
            height: "220px",
            "&.MuiDataGrid-root": {
              borderRadius: 0,
            },
            "& .MuiDataGrid-main .MuiDataGrid-row--lastVisible .MuiDataGrid-cell":
            {
              borderBottomColor: "transparent",
            },
          }}
          hideFooter
        />
      </TabPanel>
    </Box>
  );
}
